@@ -852,8 +852,8 @@ typedef struct
 /* edit list */
 typedef struct
   {
-  long duration;
-  long time;
+  uint32_t duration;
+  int32_t time;
   float rate;
   } quicktime_elst_table_t;
 
@@ -919,6 +919,8 @@ typedef struct
   int chunk_num;
   int chunk_samples;
   
+  int64_t pts_offset;
+  
   } quicktime_trak_t;
 
 
@@ -996,7 +998,7 @@ typedef struct
 typedef struct
   {
   /* Offset of end of 8 byte chunk header relative to ix->base_offset */
-  int relative_offset;
+  uint32_t relative_offset;
   /* size of data without 8 byte header */
   uint32_t size;
   } quicktime_ixtable_t;
