@@ -31,12 +31,18 @@
 
 #define LOG_DOMAIN "ffmpeg_audio"
 
-/* Different decoding functions */
-
-#if LIBAVCODEC_BUILD >= ((51<<16)+(29<<8)+0)
-#define DECODE_FUNC avcodec_decode_audio2
+#if LIBAVCODEC_BUILD >= ((53<<16)+(25<<8)+0)
+#define DECODE_AUDIO4 1
+#elif LIBAVCODEC_BUILD >= ((52<<16)+(23<<8)+0)
+#define DECODE_AUDIO3 1
 #else
-#define DECODE_FUNC avcodec_decode_audio
+#define DECODE_AUDIO2 1
+#endif
+
+#if LIBAVCODEC_BUILD >= ((53<<16)+(34<<8)+0)
+#define ENCODE_AUDIO2 1
+#else
+#define ENCODE_AUDIO 1
 #endif
 
 /* The following code was ported from gmerlin_avdecoder (http://gmerlin.sourceforge.net) */
@@ -445,7 +451,9 @@ typedef struct
   int64_t pts; /* For reading compressed packets */
 
   int header_written;
-  
+#if LIBAVCODEC_VERSION_MAJOR >= 54
+  AVDictionary * options;
+#endif
   } quicktime_ffmpeg_audio_codec_t;
 
 static int lqt_ffmpeg_delete_audio(quicktime_codec_t *codec_base)
@@ -462,7 +470,11 @@ static int lqt_ffmpeg_delete_audio(quicktime_codec_t *codec_base)
   if(codec->chunk_buffer)
     free(codec->chunk_buffer);
   if(codec->extradata)
-    free(codec->extradata); 
+    free(codec->extradata);
+#if LIBAVCODEC_VERSION_MAJOR >= 54
+  if(codec->options)
+    av_dict_free(&codec->options);
+#endif
   free(codec);
   return 0;
   }
@@ -473,7 +485,11 @@ static int set_parameter(quicktime_t *file,
                   const void *value)
   {
   quicktime_ffmpeg_audio_codec_t *codec = file->atracks[track].codec->priv;
-  lqt_ffmpeg_set_parameter(codec->avctx, key, value);
+  lqt_ffmpeg_set_parameter(codec->avctx,
+#if LIBAVCODEC_VERSION_MAJOR >= 54
+                           &codec->options,
+#endif
+                           key, value);
   return 0;
   }
 
@@ -489,6 +505,11 @@ static int decode_chunk_vbr(quicktime_t * file, int track)
   quicktime_audio_map_t *track_map = &file->atracks[track];
   quicktime_ffmpeg_audio_codec_t *codec = track_map->codec->priv;
 
+#if DECODE_AUDIO4
+  AVFrame f;
+  int got_frame;
+#endif
+  
   chunk_packets = lqt_audio_num_vbr_packets(file, track, track_map->cur_chunk, &num_samples);
 
   if(!chunk_packets)
@@ -513,38 +534,57 @@ static int decode_chunk_vbr(quicktime_t * file, int track)
     if(!packet_size)
       return 0;
 
-#if LIBAVCODEC_BUILD >= 3349760
     bytes_decoded = codec->sample_buffer_alloc -
       (codec->sample_buffer_end - codec->sample_buffer_start);
     bytes_decoded *= 2 * track_map->channels;
-#else
-    bytes_decoded = 0;
-#endif
 
-#if LIBAVCODEC_BUILD >= ((52<<16)+(26<<8)+0)
+#if DECODE_AUDIO3 || DECODE_AUDIO4
     codec->pkt.data = codec->chunk_buffer;
     codec->pkt.size = packet_size + FF_INPUT_BUFFER_PADDING_SIZE;
+
+#if DECODE_AUDIO4
+    frame_bytes = avcodec_decode_audio4(codec->avctx, &f,
+                                        &got_frame, &codec->pkt);
+    if(frame_bytes < 0)
+      {
+      lqt_log(file, LQT_LOG_ERROR, LOG_DOMAIN, "avcodec_decode_audio4 error");
+      break;
+      }
+    bytes_decoded = f.nb_samples * 2 * track_map->channels;
+    memcpy(&codec->sample_buffer[track_map->channels *
+                                 (codec->sample_buffer_end -
+                                  codec->sample_buffer_start)],
+           f.extended_data[0],
+           bytes_decoded);
     
+#else // DECODE_AUDIO3
     frame_bytes = avcodec_decode_audio3(codec->avctx,
                                         &codec->sample_buffer[track_map->channels *
                                                                (codec->sample_buffer_end -
                                                                 codec->sample_buffer_start)],
                                         &bytes_decoded,
                                         &codec->pkt);
-#else
+    if(frame_bytes < 0)
+      {
+      lqt_log(file, LQT_LOG_ERROR, LOG_DOMAIN, "avcodec_decode_audio3 error");
+      break;
+      }
+#endif // DECODE_AUDIO3
+    
+#else // DECODE_AUDIO2
     frame_bytes =
-      DECODE_FUNC(codec->avctx,
+      avcodec_decode_audio2(codec->avctx,
                   &codec->sample_buffer[track_map->channels *
                                          (codec->sample_buffer_end - codec->sample_buffer_start)],
                   &bytes_decoded,
                   codec->chunk_buffer,
                   packet_size + FF_INPUT_BUFFER_PADDING_SIZE);
-#endif
     if(frame_bytes < 0)
       {
-      lqt_log(file, LQT_LOG_ERROR, LOG_DOMAIN, "avcodec_decode_audio error");
+      lqt_log(file, LQT_LOG_ERROR, LOG_DOMAIN, "avcodec_decode_audio2 error");
       break;
       }
+#endif
     codec->sample_buffer_end += (bytes_decoded / (track_map->channels * 2));
     }
   track_map->cur_chunk++;
@@ -568,6 +608,11 @@ static int decode_chunk(quicktime_t * file, int track)
   quicktime_audio_map_t *track_map = &file->atracks[track];
   quicktime_ffmpeg_audio_codec_t *codec = track_map->codec->priv;
 
+#if DECODE_AUDIO4
+  AVFrame f;
+  int got_frame;
+#endif
+  
   /* Read chunk */
   
   chunk_size = lqt_append_audio_chunk(file,
@@ -705,32 +750,50 @@ static int decode_chunk(quicktime_t * file, int track)
      *  size in BYTES.
      */
 
-#if LIBAVCODEC_BUILD >= 3349760
     bytes_decoded = codec->sample_buffer_alloc -
       (codec->sample_buffer_end - codec->sample_buffer_start);
     bytes_decoded *= 2 * track_map->channels;
-#else
-    bytes_decoded = 0;
-#endif
 
-#if LIBAVCODEC_BUILD >= ((52<<16)+(26<<8)+0)
+#if DECODE_AUDIO3 || DECODE_AUDIO4
     codec->pkt.data = &codec->chunk_buffer[bytes_used];
     codec->pkt.size = codec->bytes_in_chunk_buffer + FF_INPUT_BUFFER_PADDING_SIZE;
+
+#if DECODE_AUDIO4
     
+    frame_bytes = avcodec_decode_audio4(codec->avctx, &f,
+                                        &got_frame, &codec->pkt);
+    if(frame_bytes < 0)
+      {
+      lqt_log(file, LQT_LOG_ERROR, LOG_DOMAIN, "avcodec_decode_audio4 error");
+      break;
+      }
+    bytes_decoded = f.nb_samples * 2 * track_map->channels;
+    memcpy(&codec->sample_buffer[track_map->channels *
+                                 (codec->sample_buffer_end -
+                                  codec->sample_buffer_start)],
+           f.extended_data[0],
+           bytes_decoded);
+    
+#else // DECODE_AUDIO3
     frame_bytes =
       avcodec_decode_audio3(codec->avctx,
                             &codec->sample_buffer[track_map->channels *
                                                    (codec->sample_buffer_end - codec->sample_buffer_start)],
                             &bytes_decoded,
                             &codec->pkt);
-#else
+
+#endif
+
+    
+    
+#else // DECODE_AUDIO2
     frame_bytes =
-      DECODE_FUNC(codec->avctx,
-                  &codec->sample_buffer[track_map->channels *
-                                        (codec->sample_buffer_end - codec->sample_buffer_start)],
-                  &bytes_decoded,
-                  &codec->chunk_buffer[bytes_used],
-                  codec->bytes_in_chunk_buffer + FF_INPUT_BUFFER_PADDING_SIZE);
+      avcodec_decode_audio2(codec->avctx,
+                            &codec->sample_buffer[track_map->channels *
+                                                  (codec->sample_buffer_end - codec->sample_buffer_start)],
+                            &bytes_decoded,
+                            &codec->chunk_buffer[bytes_used],
+                            codec->bytes_in_chunk_buffer + FF_INPUT_BUFFER_PADDING_SIZE);
 #endif
     if(frame_bytes < 0)
       {
@@ -957,12 +1020,20 @@ static int lqt_ffmpeg_decode_audio(quicktime_t *file, void * output, long sample
    
     codec->avctx->codec_id = codec->decoder->id;
     codec->avctx->codec_type = codec->decoder->type;
- 
+
+#if LIBAVCODEC_VERSION_MAJOR < 54
     if(avcodec_open(codec->avctx, codec->decoder) != 0)
       {
-      lqt_log(file, LQT_LOG_ERROR, LOG_DOMAIN, "Avcodec open failed");
+      lqt_log(file, LQT_LOG_ERROR, LOG_DOMAIN, "avcodec_open failed");
       return 0;
       }
+#else
+    if(avcodec_open2(codec->avctx, codec->decoder, NULL) != 0)
+      {
+      lqt_log(file, LQT_LOG_ERROR, LOG_DOMAIN, "avcodec_open2 failed");
+      return 0;
+      }
+#endif
     
     //    codec->sample_buffer_offset = 0;
     codec->initialized = 1;
@@ -1108,7 +1179,7 @@ static void create_dac3_atom(quicktime_t * file, int track, uint8_t * buf)
 
 
 static int lqt_ffmpeg_encode_audio(quicktime_t *file, void * input,
-                            long samples, int track)
+                                   long samples, int track)
   {
   int result = -1;
   quicktime_audio_map_t *track_map = &file->atracks[track];
@@ -1119,7 +1190,12 @@ static int lqt_ffmpeg_encode_audio(quicktime_t *file, void * input,
   int samples_done = 0;
   int samples_encoded;
   /* Initialize encoder */
-    
+#if ENCODE_AUDIO2
+  AVFrame f;
+  AVPacket pkt;
+  int got_packet;
+#endif
+  
   if(!codec->initialized)
     {
     codec->avctx->sample_rate = track_map->samplerate;
@@ -1128,11 +1204,22 @@ static int lqt_ffmpeg_encode_audio(quicktime_t *file, void * input,
     codec->avctx->codec_id = codec->encoder->id;
     codec->avctx->codec_type = codec->encoder->type;
 
+    codec->avctx->sample_fmt = codec->encoder->sample_fmts[0];
+
+    
+#if LIBAVCODEC_VERSION_MAJOR < 54
     if(avcodec_open(codec->avctx, codec->encoder) != 0)
       {
-      lqt_log(file, LQT_LOG_ERROR, LOG_DOMAIN, "Avcodec open failed");
-      return -1;
+      lqt_log(file, LQT_LOG_ERROR, LOG_DOMAIN, "avcodec_open failed");
+      return 0;
       }
+#else
+    if(avcodec_open2(codec->avctx, codec->encoder, NULL) != 0)
+      {
+      lqt_log(file, LQT_LOG_ERROR, LOG_DOMAIN, "avcodec_open2 failed");
+      return 0;
+      }
+#endif
     
     codec->initialized = 1;
 
@@ -1169,21 +1256,38 @@ static int lqt_ffmpeg_encode_audio(quicktime_t *file, void * input,
   
   while(codec->samples_in_buffer >= codec->avctx->frame_size)
     {
+#if ENCODE_AUDIO2
+    av_init_packet(&pkt);
+    pkt.data = codec->chunk_buffer;
+    pkt.size = codec->chunk_buffer_alloc;
+
+    avcodec_get_frame_defaults(&f);
+    f.nb_samples = codec->avctx->frame_size;
     
+    avcodec_fill_audio_frame(&f, channels, codec->avctx->sample_fmt,
+                             (uint8_t*)&codec->sample_buffer[samples_done*channels],
+                             codec->avctx->frame_size * channels * 2, 
+                             1);
+
+    if(avcodec_encode_audio2(codec->avctx, &pkt,
+                             &f, &got_packet) < 0)
+      return 0;
+
+    if(got_packet && pkt.size)
+      frame_bytes = pkt.size;
+    else
+      frame_bytes = 0;
+
+#else
     frame_bytes = avcodec_encode_audio(codec->avctx, codec->chunk_buffer,
                                        codec->chunk_buffer_alloc,
                                        &codec->sample_buffer[samples_done*channels]);
+#endif
+    
     if(frame_bytes > 0)
       {
       quicktime_write_chunk_header(file, trak);
-#if 0    // PATCH 3  
-      if(codec->avctx->frame_size == 1)
-        samples_encoded = codec->samples_in_buffer;
-      else
-#endif
-        samples_encoded = codec->avctx->frame_size;
-
-
+      samples_encoded = codec->avctx->frame_size;
       samples_done              += samples_encoded;
       codec->samples_in_buffer  -= samples_encoded;
       
@@ -1262,7 +1366,9 @@ static int read_packet_mpa(quicktime_t * file, lqt_packet_t * p, int track)
   return 1;
   }
 
-static int writes_compressed_mp2(lqt_file_type_t type, const lqt_compression_info_t * ci)
+#if 0
+static int writes_compressed_mp2(lqt_file_type_t type,
+                                 const lqt_compression_info_t * ci)
   {
   return 1;
   }
@@ -1273,7 +1379,6 @@ static int init_compressed_mp2(quicktime_t * file, int track)
   return 0;
   }
 
-#if 0
 static int init_compressed_ac3(quicktime_t * file, int track)
   {
   
@@ -1297,7 +1402,7 @@ static int write_packet_ac3(quicktime_t * file, lqt_packet_t * p, int track)
     }
   
   quicktime_write_chunk_header(file, atrack->track);
-  result = quicktime_write_data(file, p->data, p->data_len);
+  result = !quicktime_write_data(file, p->data, p->data_len);
   
   atrack->track->chunk_samples = p->duration;
   quicktime_write_chunk_footer(file, atrack->track);
@@ -1369,14 +1474,18 @@ void quicktime_init_audio_codec_ffmpeg(quicktime_codec_t * codec_base,
   {
   quicktime_ffmpeg_audio_codec_t *codec;
   
-  avcodec_init();
+  //  avcodec_init();
   codec = calloc(1, sizeof(*codec));
   if(!codec)
     return;
   
   codec->encoder = encoder;
   codec->decoder = decoder;
-  codec-> avctx = avcodec_alloc_context();
+#if LIBAVCODEC_VERSION_INT < ((53<<16)|(8<<8)|0)
+  codec->avctx = avcodec_alloc_context();
+#else
+  codec->avctx = avcodec_alloc_context3(NULL);
+#endif
   codec_base->priv = (void *)codec;
 
   codec_base->delete_codec = lqt_ffmpeg_delete_audio;
