@@ -813,7 +813,7 @@ struct CODECIDMAP codecidmap_v[] =
       .wav_ids = { LQT_WAV_ID_NONE },
       .compatibility_flags = LQT_FILE_QT,
       .do_encode = 1,
-      .encoding_colormodels = (int[]){ BC_YUV422P, BC_YUVJ422P, LQT_COLORMODEL_NONE }
+      .encoding_colormodels = (int[]){ BC_YUV422P, BC_YUVJ422P, BC_YUV422P10, BC_YUVJ422P10, LQT_COLORMODEL_NONE }
     },
 #endif
     {
@@ -948,7 +948,7 @@ static void ffmpeg_map_init(void)
     }
     
   avcodec_register_all();
-  avcodec_init();
+  //  avcodec_init();
   ffmpeg_num_video_codecs = 0;
   ffmpeg_num_audio_codecs = 0;
   
