@@ -36,8 +36,18 @@
 #include SWSCALE_HEADER
 #endif
 
-// Enable interlaced encoding (experimental)
-// #define DO_INTERLACE
+
+#ifdef  PIX_FMT_YUV422P10
+#define PIX_FMT_YUV422P10_OR_DUMMY PIX_FMT_YUV422P10
+#else
+#define PIX_FMT_YUV422P10_OR_DUMMY -1234
+#endif
+
+#if LIBAVCODEC_VERSION_INT >= ((54<<16)|(1<<8)|0)
+#define ENCODE_VIDEO2 1
+#else
+#define ENCODE_VIDEO 1
+#endif
 
 /* We keep the numeric values the same as in the ACLR atom.
    The interpretation of values is based on trial and error. */
@@ -86,9 +96,17 @@ typedef struct
   
   int is_imx;
   int y_offset;
-  
-  AVPaletteControl palette;
 
+#if LIBAVCODEC_VERSION_MAJOR < 54
+  AVPaletteControl palette;
+#else
+  int palette_sent;
+#endif
+
+#if LIBAVCODEC_VERSION_MAJOR >= 54
+  AVDictionary * options;
+#endif
+  
   /* We decode the first frame during the init() function to
      obtain the stream colormodel */
 
@@ -125,32 +143,36 @@ static const struct
   }
 colormodels[] =
   {
-    { PIX_FMT_YUV420P,  BC_YUV420P,  1 },  ///< Planar YUV 4:2:0 (1 Cr & Cb sample per 2x2 Y samples)
+    { PIX_FMT_YUV420P,   BC_YUV420P,   1 }, ///< Planar YUV 4:2:0 (1 Cr & Cb sample per 2x2 Y samples)
 #if LIBAVUTIL_VERSION_INT < (50<<16)
-    { PIX_FMT_YUV422,   BC_YUV422,   1 },
+    { PIX_FMT_YUV422,    BC_YUV422,    1 },
 #else
-    { PIX_FMT_YUYV422,   BC_YUV422,  1 },
+    { PIX_FMT_YUYV422,   BC_YUV422,    1 },
 #endif
-    { PIX_FMT_RGB24,    BC_RGB888,   1 },  ///< Packed pixel, 3 bytes per pixel, RGBRGB...
-    { PIX_FMT_BGR24,    BC_BGR888,   1 },  ///< Packed pixel, 3 bytes per pixel, BGRBGR...
-    { PIX_FMT_YUV422P,  BC_YUV422P,  1 },  ///< Planar YUV 4:2:2 (1 Cr & Cb sample per 2x1 Y samples)
-    { PIX_FMT_YUV444P,  BC_YUV444P,  1 },  ///< Planar YUV 4:4:4 (1 Cr & Cb sample per 1x1 Y samples)
-    { PIX_FMT_YUV411P,  BC_YUV411P,  1 },  ///< Planar YUV 4:1:1 (1 Cr & Cb sample per 4x1 Y samples)
-    { PIX_FMT_RGB565,   BC_RGB565,   1 },  ///< always stored in cpu endianness
-    { PIX_FMT_YUVJ420P, BC_YUVJ420P, 1 }, ///< Planar YUV 4:2:0 full scale (jpeg)
-    { PIX_FMT_YUVJ422P, BC_YUVJ422P, 1 }, ///< Planar YUV 4:2:2 full scale (jpeg)
-    { PIX_FMT_YUVJ444P, BC_YUVJ444P, 1 }, ///< Planar YUV 4:4:4 full scale (jpeg)
+    { PIX_FMT_RGB24,     BC_RGB888,    1 }, ///< Packed pixel, 3 bytes per pixel, RGBRGB...
+    { PIX_FMT_BGR24,     BC_BGR888,    1 }, ///< Packed pixel, 3 bytes per pixel, BGRBGR...
+    { PIX_FMT_YUV422P,   BC_YUV422P,   1 }, ///< Planar YUV 4:2:2 (1 Cr & Cb sample per 2x1 Y samples)
+    { PIX_FMT_YUV444P,   BC_YUV444P,   1 }, ///< Planar YUV 4:4:4 (1 Cr & Cb sample per 1x1 Y samples)
+    { PIX_FMT_YUV411P,   BC_YUV411P,   1 }, ///< Planar YUV 4:1:1 (1 Cr & Cb sample per 4x1 Y samples)
+    { PIX_FMT_YUV422P16, BC_YUV422P16, 1 }, ///< Planar 16 bit YUV 4:2:2 (1 Cr & Cb sample per 2x1 Y samples)
+#ifdef PIX_FMT_YUV422P10
+    { PIX_FMT_YUV422P10, BC_YUV422P10, 1 }, ///< 10 bit samples in uint16_t containers, planar 4:2:2
+#endif
+    { PIX_FMT_RGB565,    BC_RGB565,    1 }, ///< always stored in cpu endianness
+    { PIX_FMT_YUVJ420P,  BC_YUVJ420P,  1 }, ///< Planar YUV 4:2:0 full scale (jpeg)
+    { PIX_FMT_YUVJ422P,  BC_YUVJ422P,  1 }, ///< Planar YUV 4:2:2 full scale (jpeg)
+    { PIX_FMT_YUVJ444P,  BC_YUVJ444P,  1 }, ///< Planar YUV 4:4:4 full scale (jpeg)
 #if LIBAVUTIL_VERSION_INT < (50<<16)
-    { PIX_FMT_RGBA32,   BC_RGBA8888, 0 },  ///< Packed pixel, 4 bytes per pixel, BGRABGRA...
+    { PIX_FMT_RGBA32,    BC_RGBA8888,  0 }, ///< Packed pixel, 4 bytes per pixel, BGRABGRA...
 #else
-    { PIX_FMT_RGB32,   BC_RGBA8888, 0 },  ///< Packed pixel, 4 bytes per pixel, BGRABGRA...
+    { PIX_FMT_RGB32,     BC_RGBA8888,  0 }, ///< Packed pixel, 4 bytes per pixel, BGRABGRA...
 #endif
-    { PIX_FMT_RGB555,   BC_RGB888,   0 },  ///< always stored in cpu endianness, most significant bit to 1
-    { PIX_FMT_GRAY8,    BC_RGB888,   0 },
-    { PIX_FMT_MONOWHITE, BC_RGB888,  0 },///< 0 is white
-    { PIX_FMT_MONOBLACK, BC_RGB888,  0 },///< 0 is black
-    { PIX_FMT_PAL8,      BC_RGB888,  0 },    ///< 8 bit with RGBA palette
-    { PIX_FMT_YUV410P,   BC_YUV420P, 0 },  ///< Planar YUV 4:1:0 (1 Cr & Cb sample per 4x4 Y samples)
+    { PIX_FMT_RGB555,    BC_RGB888,    0 }, ///< always stored in cpu endianness, most significant bit to 1
+    { PIX_FMT_GRAY8,     BC_RGB888,    0 },
+    { PIX_FMT_MONOWHITE, BC_RGB888,    0 }, ///< 0 is white
+    { PIX_FMT_MONOBLACK, BC_RGB888,    0 }, ///< 0 is black
+    { PIX_FMT_PAL8,      BC_RGB888,    0 }, ///< 8 bit with RGBA palette
+    { PIX_FMT_YUV410P,   BC_YUV420P,   0 }, ///< Planar YUV 4:1:0 (1 Cr & Cb sample per 4x4 Y samples)
   };
 
 static const struct
@@ -233,6 +255,11 @@ static int lqt_ffmpeg_delete_video(quicktime_codec_t *codec_base)
     sws_freeContext(codec->swsContext);
 #endif
 
+#if LIBAVCODEC_VERSION_MAJOR >= 54
+  if(codec->options)
+    av_dict_free(&codec->options);
+#endif
+  
   if(codec->tmp_rows)
     lqt_rows_free(codec->tmp_rows);
   
@@ -310,6 +337,21 @@ static void fill_avpicture(AVPicture * ret, unsigned char ** rows,
   }
 #endif
 
+static int lqt_tenbit_dnxhd_supported(AVCodec const* codec)
+  {
+  int i;
+  if (!codec->pix_fmts)
+    return 0;
+
+  for (i = 0; codec->pix_fmts[i] != PIX_FMT_NONE; ++i)
+    {
+    if (codec->pix_fmts[i] == PIX_FMT_YUV422P10_OR_DUMMY)
+      return 1;
+    }
+
+  return 0;
+  }
+
 static enum PixelFormat lqt_ffmpeg_get_ffmpeg_colormodel(int id)
   {
   int i;
@@ -360,20 +402,24 @@ static void lqt_ffmpeg_setup_decoding_colormodel(quicktime_t *file, quicktime_vi
   /* First we try codec-specific colormodel matching. */
   if(codec->decoder->id == CODEC_ID_DNXHD)
     {
-    /* PIX_FMT_YUV422P is the only pixel format supported by FFMpeg's DNxHD codec,
-       at least until they implement 10 bit DNxHD. */
-    if (codec->avctx->pix_fmt == PIX_FMT_YUV422P)
+    /* FFMpeg supports PIX_FMT_YUV422P and PIX_FMT_YUV422P10 for DNxHD, which
+       we sometimes interpret as PIX_FMT_YUVJ422P and PIX_FMT_YUVJ422P10. */
+    if (codec->avctx->pix_fmt == PIX_FMT_YUV422P || codec->avctx->pix_fmt == PIX_FMT_YUV422P10_OR_DUMMY)
       {
+      int p10 = (codec->avctx->pix_fmt == PIX_FMT_YUV422P10_OR_DUMMY);
       *exact = 1;
       if (lqt_ffmpeg_get_avid_yuv_range(vtrack->track) == AVID_FULL_YUV_RANGE)
         {
-          vtrack->stream_cmodel = BC_YUVJ422P;
-          codec->reinterpret_pix_fmt = PIX_FMT_YUVJ422P;
+        vtrack->stream_cmodel = p10 ? BC_YUVJ422P10 : BC_YUVJ422P;
+        codec->reinterpret_pix_fmt = p10 ? PIX_FMT_YUV422P10_OR_DUMMY : PIX_FMT_YUVJ422P;
+        // Note: reinterpret_pix_fmt should really be PIX_FMT_YUVJ422P10, except
+        // there is no such colormodel in FFMpeg. Fortunately, it's not a problem
+        // in this case, as reinterpret_pix_fmt is only used when *exact == 0.
         }
       else
         {
-        vtrack->stream_cmodel = BC_YUV422P;
-        codec->reinterpret_pix_fmt = PIX_FMT_YUV422P;
+        vtrack->stream_cmodel = p10 ? BC_YUV422P10 : BC_YUV422P;
+        codec->reinterpret_pix_fmt = p10 ? PIX_FMT_YUV422P10_OR_DUMMY : PIX_FMT_YUV422P;
         }
       return;
       }
@@ -394,8 +440,15 @@ static void lqt_ffmpeg_setup_encoding_colormodel(quicktime_video_map_t *vtrack)
 
   if (codec->encoder->id == CODEC_ID_DNXHD)
     {
-    /* FFMpeg's DNxHD encoder doesn't know anything about YUVJ422P. */
+    /* FFMpeg's DNxHD encoder only supports PIX_FMT_YUV422P and PIX_FMT_YUV422P10
+       and doesn't know anything about PIX_FMT_YUVJ422P and PIX_FMT_YUVJ422P10
+       (in fact, the latter doesn't even exist) */
     codec->avctx->pix_fmt = PIX_FMT_YUV422P;
+    if (vtrack->stream_cmodel == BC_YUV422P10 || vtrack->stream_cmodel == BC_YUVJ422P10)
+      {
+      if (lqt_tenbit_dnxhd_supported(codec->encoder))
+        codec->avctx->pix_fmt = PIX_FMT_YUV422P10_OR_DUMMY;
+      }
     }
   }
 
@@ -736,6 +789,7 @@ static int lqt_ffmpeg_decode_video(quicktime_t *file, unsigned char **row_pointe
     /* Add palette info */
     
     ctab = &trak->mdia.minf.stbl.stsd.table->ctab;
+#if LIBAVCODEC_VERSION_MAJOR < 54
     if(ctab->size)
       {
       codec->avctx->palctrl = &codec->palette;
@@ -753,16 +807,28 @@ static int lqt_ffmpeg_decode_video(quicktime_t *file, unsigned char **row_pointe
           ((ctab->blue[i] >> 8));
         }
       }
-    
+#else
+    /* Palette will be sent later */
+    if(!ctab->size)
+      codec->palette_sent = 1;
+#endif
     //    codec->avctx->get_buffer = avcodec_default_get_buffer;
     //    codec->avctx->release_buffer = avcodec_default_release_buffer;
 
     codec->avctx->codec_id = codec->decoder->id;
     codec->avctx->codec_type = codec->decoder->type;
- 
+
+#if LIBAVCODEC_VERSION_INT < ((52<<16)+(112<<8)+0)
     avcodec_thread_init(codec->avctx, codec->avctx->thread_count);
+#endif
+    
+#if LIBAVCODEC_VERSION_MAJOR < 54
     if(avcodec_open(codec->avctx, codec->decoder) != 0)
       return -1;
+#else
+    if(avcodec_open2(codec->avctx, codec->decoder, NULL) != 0)
+      return -1;
+#endif
     codec->frame = avcodec_alloc_frame();
     vtrack->stream_cmodel = LQT_COLORMODEL_NONE;
     codec->initialized = 1;
@@ -786,6 +852,32 @@ static int lqt_ffmpeg_decode_video(quicktime_t *file, unsigned char **row_pointe
 #if LIBAVCODEC_BUILD >= ((52<<16)+(26<<8)+0)
       codec->pkt.data = codec->buffer;
       codec->pkt.size = buffer_size;
+
+#if LIBAVCODEC_VERSION_MAJOR >= 54
+      if(!codec->palette_sent)
+        {
+        uint32_t * pal_i;
+        ctab = &trak->mdia.minf.stbl.stsd.table->ctab;
+        pal_i =
+          (uint32_t*)av_packet_new_side_data(&codec->pkt, AV_PKT_DATA_PALETTE,
+                                             AVPALETTE_COUNT * 4);
+        imax =
+          (ctab->size > AVPALETTE_COUNT)
+            ? AVPALETTE_COUNT : ctab->size;
+
+        for(i = 0; i < imax; i++)
+          {
+          pal_i[i] =
+            ((ctab->alpha[i] >> 8) << 24) |
+            ((ctab->red[i] >> 8) << 16) |
+            ((ctab->green[i] >> 8) << 8) |
+            ((ctab->blue[i] >> 8));
+          }
+        for(i = imax; i < AVPALETTE_COUNT; i++)
+          pal_i[i] = 0;
+        }
+#endif
+      
       if(avcodec_decode_video2(codec->avctx,
                                codec->frame,
                                &got_pic,
@@ -794,6 +886,19 @@ static int lqt_ffmpeg_decode_video(quicktime_t *file, unsigned char **row_pointe
         lqt_log(file, LQT_LOG_ERROR, LOG_DOMAIN, "Skipping corrupted frame");
         continue;
         }
+
+#if LIBAVCODEC_VERSION_MAJOR >= 54
+      /* Ugly hack: Need to free the side data elements manually because
+         ffmpeg has no public API for that */
+      if(!codec->palette_sent)
+        {
+        av_free(codec->pkt.side_data[0].data);
+        av_freep(&codec->pkt.side_data);
+        codec->pkt.side_data_elems = 0;
+        }
+#endif
+      
+
 #else
     
       if(avcodec_decode_video(codec->avctx,
@@ -1037,8 +1142,14 @@ static int init_imx_encoder(quicktime_t *file, int track)
   codec->avctx->rtp_payload_size = 1; // ??
   codec->avctx->rc_buffer_aggressivity = 0.25;
   codec->avctx->flags |= CODEC_FLAG_INTERLACED_DCT|CODEC_FLAG_LOW_DELAY;
-  codec->avctx->flags2 |= CODEC_FLAG2_INTRA_VLC|CODEC_FLAG2_NON_LINEAR_QUANT;
 
+#if (LIBAVCODEC_VERSION_MAJOR < 54)
+  codec->avctx->flags2 |= CODEC_FLAG2_INTRA_VLC|CODEC_FLAG2_NON_LINEAR_QUANT;
+#else
+  av_dict_set(&codec->options, "non_linear_quant", "1", 0);
+  av_dict_set(&codec->options, "intra_vlc", "1", 0);
+#endif
+  
   codec->avctx->bit_rate = codec->imx_bitrate * 1000000;
   
   codec->avctx->rc_max_rate = codec->avctx->bit_rate;
@@ -1106,12 +1217,16 @@ static void setup_header_mpeg4(quicktime_t *file, int track,
   
   }
 
-static void setup_avid_atoms(quicktime_t* file, quicktime_video_map_t *vtrack, uint8_t const* enc_data, int enc_data_size)
+static void setup_avid_atoms(quicktime_t* file,
+                             quicktime_video_map_t *vtrack,
+                             uint8_t const* enc_data, int enc_data_size)
   {
   uint8_t* p;
   uint8_t ACLR_atom[16];
   uint8_t APRG_atom[16];
   uint8_t ARES_atom[112];
+  int full_range_yuv = (vtrack->stream_cmodel == BC_YUVJ422P ||
+                        vtrack->stream_cmodel == BC_YUVJ422P10);
 
   if (enc_data_size < 0x2c)
     {
@@ -1122,7 +1237,7 @@ static void setup_avid_atoms(quicktime_t* file, quicktime_video_map_t *vtrack, u
   p = ACLR_atom;
   lqt_ffmpeg_write_tag(&p, "ACLR");
   lqt_ffmpeg_write_tag(&p, "0001");
-  lqt_ffmpeg_write_be32(&p, vtrack->stream_cmodel == BC_YUVJ422P ? AVID_FULL_YUV_RANGE : AVID_NORMAL_YUV_RANGE);
+  lqt_ffmpeg_write_be32(&p, full_range_yuv ? AVID_FULL_YUV_RANGE : AVID_NORMAL_YUV_RANGE);
   lqt_ffmpeg_write_be32(&p, 0); /* unknown */
   quicktime_stsd_set_user_atom(vtrack->track, "ACLR", ACLR_atom, sizeof(ACLR_atom));
 
@@ -1173,6 +1288,13 @@ static int lqt_ffmpeg_encode_video(quicktime_t *file, unsigned char **row_pointe
   int height = trak->tkhd.track_height;
   int width = trak->tkhd.track_width;
   int stats_len;
+#if ENCODE_VIDEO2
+  AVPacket pkt;
+  int got_packet;
+#endif
+  int64_t pts;
+  int kf;
+  
   if(!row_pointers)
     {
     if(vtrack->stream_cmodel == BC_YUV420P)
@@ -1180,20 +1302,16 @@ static int lqt_ffmpeg_encode_video(quicktime_t *file, unsigned char **row_pointe
       if(codec->encoder->id == CODEC_ID_MPEG4)
         {
         vtrack->chroma_placement = LQT_CHROMA_PLACEMENT_MPEG2;
-#ifndef DO_INTERLACE // Seems not to work yet
         /* enable interlaced encoding */
         vtrack->interlace_mode = LQT_INTERLACE_NONE;
-#endif
         }
       else if(codec->encoder->id == CODEC_ID_DVVIDEO)
         {
         vtrack->chroma_placement = LQT_CHROMA_PLACEMENT_DVPAL;
         }
-#ifndef DO_INTERLACE // Seems not to work yet
       else
         /* enable interlaced encoding */
         vtrack->interlace_mode = LQT_INTERLACE_NONE;
-#endif
       }
     return 0;
     }
@@ -1328,9 +1446,17 @@ static int lqt_ffmpeg_encode_video(quicktime_t *file, unsigned char **row_pointe
     codec->avctx->codec_id = codec->decoder->id;
     codec->avctx->codec_type = codec->decoder->type;
 
+#if LIBAVCODEC_VERSION_INT < ((52<<16)+(112<<8)+0)
     avcodec_thread_init(codec->avctx, codec->avctx->thread_count);
+#endif
+
+#if LIBAVCODEC_VERSION_MAJOR < 54
     if(avcodec_open(codec->avctx, codec->encoder) != 0)
       return -1;
+#else
+    if(avcodec_open2(codec->avctx, codec->encoder, &codec->options) != 0)
+      return -1;
+#endif
     codec->buffer_alloc = codec->avctx->width * codec->avctx->height * 4 + 1024*256;
     codec->buffer = malloc(codec->buffer_alloc);
     if(!codec->buffer)
@@ -1399,23 +1525,44 @@ static int lqt_ffmpeg_encode_video(quicktime_t *file, unsigned char **row_pointe
     if(vtrack->interlace_mode == LQT_INTERLACE_TOP_FIRST)
       codec->frame->top_field_first = 1;
     }
-#endif   
+#endif
+
+#if ENCODE_VIDEO2 // New
+  av_init_packet(&pkt);
+  pkt.data = codec->buffer;
+  pkt.size = codec->buffer_alloc;
+
+  if(avcodec_encode_video2(codec->avctx, &pkt, codec->frame, &got_packet) < 0)
+    return -1;
+
+  if(got_packet)
+    bytes_encoded = pkt.size;
+  else
+    bytes_encoded = 0;
+  
+  pts = pkt.pts;
+  kf = !!(pkt.flags & AV_PKT_FLAG_KEY);
+    
+#else // Old
+  
   bytes_encoded = avcodec_encode_video(codec->avctx,
                                        codec->buffer,
                                        codec->buffer_alloc,
                                        codec->frame);
-
+  
   if(bytes_encoded < 0)
     return -1;
-
+  
+  pts = codec->avctx->coded_frame->pts;
+  kf = codec->avctx->coded_frame->key_frame;
+  
+#endif
+  
   if(!was_initialized && codec->encoder->id == CODEC_ID_DNXHD)
-    {
     setup_avid_atoms(file, vtrack, codec->buffer, bytes_encoded);
-    }
-
+  
   if(bytes_encoded)
     {
-    int64_t pts = codec->avctx->coded_frame->pts;
     if (pts == AV_NOPTS_VALUE || (codec->encoder->id == CODEC_ID_DNXHD && pts == 0))
       {
       /* Some codecs don't bother generating presentation timestamps.
@@ -1425,7 +1572,7 @@ static int lqt_ffmpeg_encode_video(quicktime_t *file, unsigned char **row_pointe
 
     lqt_write_frame_header(file, track,
                            -1, (int)pts,
-                           codec->avctx->coded_frame->key_frame);
+                           kf);
           
     result = !quicktime_write_data(file, 
                                    codec->buffer, 
@@ -1470,25 +1617,54 @@ static int flush(quicktime_t *file, int track)
   int bytes_encoded;
   quicktime_video_map_t *vtrack = &file->vtracks[track];
   quicktime_ffmpeg_video_codec_t *codec = vtrack->codec->priv;
-
+  int64_t pts;
+  int kf;
+  
+#if ENCODE_VIDEO2
+  AVPacket pkt;
+  int got_packet;
+#endif
+  
   /* Do nothing if we didn't encode anything yet */
   if(!codec->initialized)
     return 0;
-        
+
+#if ENCODE_VIDEO2
+  av_init_packet(&pkt);
+  pkt.data = codec->buffer;
+  pkt.size = codec->buffer_alloc;
+  
+  if(avcodec_encode_video2(codec->avctx, &pkt, (AVFrame*)0, &got_packet) < 0)
+    return -1;
+
+  if(got_packet)
+    bytes_encoded = pkt.size;
+  else
+    return 0;
+  
+  pts = pkt.pts;
+
+  kf = !!(pkt.flags & AV_PKT_FLAG_KEY);
+  
+#else
+  
   bytes_encoded = avcodec_encode_video(codec->avctx,
                                        codec->buffer,
                                        codec->buffer_alloc,
                                        (AVFrame*)0);
-
-  if(bytes_encoded < 0)
+  if(bytes_encoded <= 0)
     return 0;
-        
+
+  pts = codec->avctx->coded_frame->pts;
+  kf = codec->avctx->coded_frame->key_frame;
+  
+#endif
+  
   if(bytes_encoded)
     {
     lqt_write_frame_header(file, track,
-                           -1, codec->avctx->coded_frame->pts,
-                           codec->avctx->coded_frame->key_frame);
-          
+                           -1, pts, kf);
+    
     result = !quicktime_write_data(file, 
                                    codec->buffer, 
                                    bytes_encoded);
@@ -1531,7 +1707,11 @@ static int set_parameter_video(quicktime_t *file,
     return 0;
     }
   
-  lqt_ffmpeg_set_parameter(codec->avctx, key, value);
+  lqt_ffmpeg_set_parameter(codec->avctx,
+#if LIBAVCODEC_VERSION_MAJOR >= 54
+                           &codec->options,
+#endif
+                           key, value);
 
 
 
@@ -1700,13 +1880,16 @@ void quicktime_init_video_codec_ffmpeg(quicktime_codec_t * codec_base,
   char *compressor;
   quicktime_stsd_t * stsd;
   
-  avcodec_init();
+  // avcodec_init();
 
   codec = calloc(1, sizeof(*codec));
   if(!codec)
     return;
+#if LIBAVCODEC_VERSION_INT < ((53<<16)|(8<<8)|0)
   codec->avctx = avcodec_alloc_context();
-
+#else
+  codec->avctx = avcodec_alloc_context3(NULL);
+#endif
   codec->encoder = encoder;
   codec->decoder = decoder;
   
