@@ -5,7 +5,7 @@
  http://libquicktime.sourceforge.net
 
  Copyright (C) 2002 Heroine Virtual Ltd.
- Copyright (C) 2002-2010 Members of the libquicktime project.
+ Copyright (C) 2002-2011 Members of the libquicktime project.
 
  This library is free software; you can redistribute it and/or modify it under
  the terms of the GNU Lesser General Public License as published by the Free
@@ -53,6 +53,12 @@ void lqt_set_fiel_uncompressed(quicktime_t * file, int track)
 
 int lqt_set_colr_yuv_uncompressed(quicktime_t *file,int track) {
     quicktime_colr_t colr;
+    
+    if (file->vtracks[track].track->mdia.minf.stbl.stsd.table->has_colr) {
+	/* The user has already provided a colr atom. */
+	return 0;
+    }
+    
     colr.colorParamType=LQT_COLR_NCLC;
     colr.primaries=1;
     colr.transferFunction=1;
