@@ -257,6 +257,24 @@
 						j); \
 					TRANSFER_FRAME_TAIL \
 					break; \
+                case BC_YUV422P10: \
+                    TRANSFER_YUV422P16_OUT_HEAD \
+                    transfer_RGB888_to_YUV422P10((uint16_t *)output_y, \
+                        (uint16_t *)output_u, \
+                        (uint16_t *)output_v, \
+                        (input), \
+                        j); \
+                    TRANSFER_FRAME_TAIL \
+                    break; \
+                case BC_YUVJ422P10: \
+                    TRANSFER_YUV422P16_OUT_HEAD \
+                    transfer_RGB888_to_YUVJ422P10((uint16_t *)output_y, \
+                        (uint16_t *)output_u, \
+                        (uint16_t *)output_v, \
+                        (input), \
+                        j); \
+                    TRANSFER_FRAME_TAIL \
+                    break; \
 				case BC_YUV411P: \
 					TRANSFER_YUV411P_OUT_HEAD \
 					transfer_RGB888_to_YUV411P(output_y, \
@@ -502,7 +520,25 @@
 						(uint16_t*)(input), \
 						j); \
 					TRANSFER_FRAME_TAIL \
-					break; \
+                    break; \
+                case BC_YUV422P10: \
+                    TRANSFER_YUV422P16_OUT_HEAD_16 \
+                    transfer_RGB161616_to_YUV422P10(output_y, \
+                        output_u, \
+                        output_v, \
+                        (uint16_t*)(input), \
+                        j); \
+                    TRANSFER_FRAME_TAIL \
+                    break; \
+                case BC_YUVJ422P10: \
+                    TRANSFER_YUV422P16_OUT_HEAD_16 \
+                    transfer_RGB161616_to_YUVJ422P10(output_y, \
+                        output_u, \
+                        output_v, \
+                        (uint16_t*)(input), \
+                        j); \
+                    TRANSFER_FRAME_TAIL \
+                    break; \
 				case BC_YUV444P: \
 					TRANSFER_YUV444P_OUT_HEAD \
 					transfer_RGB161616_to_YUV444P(output_y, \
