@@ -1016,6 +1016,62 @@ int quicktime_video_depth(quicktime_t *file, int track)
   return 0;
   }
 
+long lqt_video_edit_list_total_entries(quicktime_t * file, int track)
+{
+   if(track < 0 || track >= quicktime_video_tracks(file)) {
+      lqt_log(file, LQT_LOG_ERROR, LOG_DOMAIN, "illegal track index");
+      return 0;
+   }
+      
+   return file->vtracks[track].track->edts.elst.total_entries;
+}
+
+long lqt_video_edit_duration(quicktime_t * file, int track, int entry_index)
+{
+   if(track < 0 || track >= quicktime_video_tracks(file)) {
+      lqt_log(file, LQT_LOG_ERROR, LOG_DOMAIN, "illegal track index");
+      return 0;
+   }
+
+   if(entry_index < 0 || entry_index >= file->vtracks[track].track->edts.elst.total_entries) {
+      lqt_log(file, LQT_LOG_ERROR, LOG_DOMAIN, "illegal edit list entry");
+      return 0;
+   }
+
+   // convert to media timescale
+   return (long)((double)file->vtracks[track].track->edts.elst.table[entry_index].duration / file->moov.mvhd.time_scale * file->vtracks[track].track->mdia.mdhd.time_scale + 0.5);
+}
+
+long lqt_video_edit_time(quicktime_t * file, int track, int entry_index)
+{
+   if(track < 0 || track >= quicktime_video_tracks(file)) {
+      lqt_log(file, LQT_LOG_ERROR, LOG_DOMAIN, "illegal track index");
+      return 0;
+   }
+
+   if(entry_index < 0 || entry_index >= file->vtracks[track].track->edts.elst.total_entries) {
+      lqt_log(file, LQT_LOG_ERROR, LOG_DOMAIN, "illegal edit list entry");
+      return 0;
+   }
+
+   return file->vtracks[track].track->edts.elst.table[entry_index].time;
+}
+
+float lqt_video_edit_rate(quicktime_t * file, int track, int entry_index)
+{
+   if(track < 0 || track >= quicktime_video_tracks(file)) {
+      lqt_log(file, LQT_LOG_ERROR, LOG_DOMAIN, "illegal track index");
+      return 0.0f;
+   }
+
+   if(entry_index < 0 || entry_index >= file->vtracks[track].track->edts.elst.total_entries) {
+      lqt_log(file, LQT_LOG_ERROR, LOG_DOMAIN, "illegal edit list entry");
+      return 0.0f;
+   }
+
+   return file->vtracks[track].track->edts.elst.table[entry_index].rate;
+}
+
 void quicktime_set_cmodel(quicktime_t *file, int colormodel)
   {
   int i;
@@ -1116,6 +1172,15 @@ double quicktime_frame_rate(quicktime_t *file, int track)
   return 0;
   }
 
+int64_t lqt_get_frame_time(quicktime_t * file, int track, int frame)
+  {
+  int64_t dummy1;
+  int64_t dummy2;
+  return
+    quicktime_sample_to_time(&file->vtracks[track].track->mdia.minf.stbl.stts, frame,
+                             &dummy1, &dummy2);
+  }
+
 /*
  *  Return the timestamp of the NEXT frame to be decoded.
  *  Call this BEFORE one of the decoding functions.
@@ -1209,6 +1274,62 @@ int quicktime_write_audio(quicktime_t *file,
   return result;
   }
 
+long lqt_audio_edit_list_total_entries(quicktime_t * file, int track)
+{
+   if(track < 0 || track >= quicktime_audio_tracks(file)) {
+      lqt_log(file, LQT_LOG_ERROR, LOG_DOMAIN, "illegal track index");
+      return 0;
+   }
+      
+   return file->atracks[track].track->edts.elst.total_entries;
+}
+
+long lqt_audio_edit_duration(quicktime_t * file, int track, int entry_index)
+{
+   if(track < 0 || track >= quicktime_audio_tracks(file)) {
+      lqt_log(file, LQT_LOG_ERROR, LOG_DOMAIN, "illegal track index");
+      return 0;
+   }
+
+   if(entry_index < 0 || entry_index >= file->atracks[track].track->edts.elst.total_entries) {
+      lqt_log(file, LQT_LOG_ERROR, LOG_DOMAIN, "illegal edit list entry");
+      return 0;
+   }
+
+   // convert to media timescale
+   return (long)((double)file->atracks[track].track->edts.elst.table[entry_index].duration / file->moov.mvhd.time_scale * file->atracks[track].track->mdia.mdhd.time_scale + 0.5);
+}
+
+long lqt_audio_edit_time(quicktime_t * file, int track, int entry_index)
+{
+   if(track < 0 || track >= quicktime_audio_tracks(file)) {
+      lqt_log(file, LQT_LOG_ERROR, LOG_DOMAIN, "illegal track index");
+      return 0;
+   }
+
+   if(entry_index < 0 || entry_index >= file->atracks[track].track->edts.elst.total_entries) {
+      lqt_log(file, LQT_LOG_ERROR, LOG_DOMAIN, "illegal edit list entry");
+      return 0;
+   }
+
+   return file->atracks[track].track->edts.elst.table[entry_index].time;
+}
+
+float lqt_audio_edit_rate(quicktime_t * file, int track, int entry_index)
+{
+   if(track < 0 || track >= quicktime_audio_tracks(file)) {
+      lqt_log(file, LQT_LOG_ERROR, LOG_DOMAIN, "illegal track index");
+      return 0.0f;
+   }
+
+   if(entry_index < 0 || entry_index >= file->atracks[track].track->edts.elst.total_entries) {
+      lqt_log(file, LQT_LOG_ERROR, LOG_DOMAIN, "illegal edit list entry");
+      return 0.0f;
+   }
+
+   return file->atracks[track].track->edts.elst.table[entry_index].rate;
+}
+
 int quicktime_write_frame(quicktime_t *file,
                           unsigned char *video_buffer,
                           int64_t bytes, int track)
@@ -1456,9 +1577,20 @@ int quicktime_delete_audio_map(quicktime_audio_map_t *atrack)
 
 // Initialize maps, for reading only
 
+
+
 void quicktime_init_maps(quicktime_t * file)
   {
   int i, j, k, dom, track;
+
+  /* Initialize trak for reading */
+
+  for(i = 0; i < file->moov.total_tracks; i++)
+    {
+    quicktime_trak_fix_counts(file, file->moov.trak[i],
+                              file->moov.mvhd.time_scale);
+    }
+  
   /* get tables for all the different tracks */
   file->total_atracks = quicktime_audio_tracks(file);
 
@@ -2791,3 +2923,112 @@ void lqt_set_max_riff_size(quicktime_t * file, int size)
   {
   file->max_riff_size = size * 1024 * 1024;
   }
+
+/* PTS offsets */
+
+/** \ingroup audio_encode
+ *  \brief Set an audio pts offset
+ *  \param file A quicktime handle
+ *  \param track Track index (starting with 0)
+ *  \param offset PTS of the first audio sample (in samples)
+ */
+
+void lqt_set_audio_pts_offset(quicktime_t * file, int track, int64_t offset)
+  {
+  quicktime_trak_t * trak;
+
+  if((track < 0) && (track >= file->total_atracks))
+    return;
+
+  trak = file->atracks[track].track;
+  trak->pts_offset = offset;
+  }
+  
+/** \ingroup audio_decode
+ *  \brief Get an audio pts offset
+ *  \param file A quicktime handle
+ *  \param track Track index (starting with 0)
+ *  \returns PTS of the first audio sample (in samples)
+ */
+
+int64_t lqt_get_audio_pts_offset(quicktime_t * file, int track)
+  {
+  quicktime_trak_t * trak;
+  if((track < 0) && (track >= file->total_atracks))
+    return 0;
+
+  trak = file->atracks[track].track;
+  return trak->pts_offset;
+  }
+
+
+/** \ingroup video_encode
+ *  \brief Set an video pts offset
+ *  \param file A quicktime handle
+ *  \param track Track index (starting with 0)
+ *  \param offset PTS of the first video frame (in timescale units)
+ */
+
+void lqt_set_video_pts_offset(quicktime_t * file, int track, int64_t offset)
+  {
+  quicktime_trak_t * trak;
+  if((track < 0) && (track >= file->total_vtracks))
+    return;
+  trak = file->vtracks[track].track;
+  trak->pts_offset = offset;
+  }
+
+  
+/** \ingroup video_decode
+ *  \brief Get an video pts offset
+ *  \param file A quicktime handle
+ *  \param track Track index (starting with 0)
+ *  \returns PTS of the first video frame (in timescale units)
+ */
+
+int64_t lqt_get_video_pts_offset(quicktime_t * file, int track)
+  {
+  quicktime_trak_t * trak;
+  if((track < 0) && (track >= file->total_vtracks))
+    return 0;
+  trak = file->vtracks[track].track;
+  return trak->pts_offset;
+
+  }
+
+
+/** \ingroup text_encode
+ *  \brief Set an video pts offset
+ *  \param file A quicktime handle
+ *  \param track Track index (starting with 0)
+ *  \param offset PTS offset of the subtitles (in timescale units)
+ */
+
+void lqt_set_text_pts_offset(quicktime_t * file, int track, int64_t offset)
+  {
+  quicktime_trak_t * trak;
+  if((track < 0) && (track >= file->total_ttracks))
+    return;
+  trak = file->ttracks[track].track;
+  trak->pts_offset = offset;
+  
+  }
+
+  
+/** \ingroup text_decode
+ *  \brief Get an video pts offset
+ *  \param file A quicktime handle
+ *  \param track Track index (starting with 0)
+ *  \returns PTS offset of the subtitles (in timescale units)
+ */
+
+int64_t lqt_get_text_pts_offset(quicktime_t * file, int track)
+  {
+  quicktime_trak_t * trak;
+  if((track < 0) && (track >= file->total_ttracks))
+    return 0;
+  trak = file->ttracks[track].track;
+  return trak->pts_offset;
+  
+  }
+
